@@ -116,8 +116,11 @@ class PVSystem(object):
                  modules_per_string=1, strings_per_inverter=1,
                  inverter=None, inverter_parameters=None,
                  racking_model='open_rack_cell_glassback',
+                 name=None,
                  **kwargs):
 
+        self.name = name
+
         self.surface_tilt = surface_tilt
         self.surface_azimuth = surface_azimuth
 
@@ -130,13 +133,19 @@ class PVSystem(object):
 
         # could tie these together with @property
         self.module = module
-        self.module_parameters = module_parameters
+        if module_parameters is None:
+            self.module_parameters = {}
+        else:
+            self.module_parameters = module_parameters
 
         self.modules_per_string = modules_per_string
         self.strings_per_inverter = strings_per_inverter
 
         self.inverter = inverter
-        self.inverter_parameters = inverter_parameters
+        if inverter_parameters is None:
+            self.inverter_parameters = {}
+        else:
+            self.inverter_parameters = inverter_parameters
 
         self.racking_model = racking_model
 
@@ -144,10 +153,10 @@ class PVSystem(object):
         super(PVSystem, self).__init__(**kwargs)
 
     def __repr__(self):
-        return ('PVSystem with tilt:' + str(self.surface_tilt) +
-                ' and azimuth: ' + str(self.surface_azimuth) +
-                ' with Module: ' + str(self.module) +
-                ' and Inverter: ' + str(self.inverter))
+        attrs = ['name', 'surface_tilt', 'surface_azimuth', 'module',
+                 'inverter', 'albedo', 'racking_model']
+        return ('PVSystem: \n  ' + '\n  '.join(
+            (attr + ': ' + str(getattr(self, attr)) for attr in attrs)))
 
     def get_aoi(self, solar_zenith, solar_azimuth):
         """Get the angle of incidence on the system.
@@ -459,6 +468,9 @@ class PVSystem(object):
         """
         return snlinverter(v_dc, p_dc, self.inverter_parameters)
 
+    def adrinverter(self, v_dc, p_dc):
+        return adrinverter(v_dc, p_dc, self.inverter_parameters)
+
     def scale_voltage_current_power(self, data):
         """
         Scales the voltage, current, and power of the DataFrames
@@ -489,9 +501,12 @@ class PVSystem(object):
 
         See :py:func:`pvwatts_dc` for details.
         """
+        kwargs = _build_kwargs(['temp_ref'], self.module_parameters)
+
         return pvwatts_dc(g_poa_effective, temp_cell,
                           self.module_parameters['pdc0'],
-                          self.module_parameters['gamma_pdc'])
+                          self.module_parameters['gamma_pdc'],
+                          **kwargs)
 
     def pvwatts_losses(self, **kwargs):
         """
@@ -512,8 +527,10 @@ class PVSystem(object):
 
         See :py:func:`pvwatts_ac` for details.
         """
-        return pvwatts_ac(pdc, self.module_parameters['pdc0'],
-                          eta_inv_nom=self.inverter_parameters['eta_inv_nom'])
+        kwargs = _build_kwargs(['eta_inv_nom', 'eta_inv_ref'],
+                               self.inverter_parameters)
+
+        return pvwatts_ac(pdc, self.module_parameters['pdc0'], **kwargs)
 
     def localize(self, location=None, latitude=None, longitude=None,
                  **kwargs):
@@ -570,12 +587,12 @@ class LocalizedPVSystem(PVSystem, Location):
         super(LocalizedPVSystem, self).__init__(**new_kwargs)
 
     def __repr__(self):
-        return ('LocalizedPVSystem with tilt:' + str(self.surface_tilt) +
-                ' and azimuth: ' + str(self.surface_azimuth) +
-                ' with Module: ' + str(self.module) +
-                ' and Inverter: ' + str(self.inverter) +
-                ' at Latitude: ' + str(self.latitude) +
-                ' and Longitude: ' + str(self.longitude))
+        attrs = [
+            'name', 'latitude', 'longitude', 'altitude', 'tz', 'surface_tilt',
+            'surface_azimuth', 'module', 'inverter', 'albedo', 'racking_model'
+                 ]
+        return ('LocalizedPVSystem: \n  ' + '\n  '.join(
+            (attr + ': ' + str(getattr(self, attr)) for attr in attrs)))
 
 
 def systemdef(meta, surface_tilt, surface_azimuth, albedo, modules_per_string,
@@ -1048,6 +1065,7 @@ def retrieve_sam(name=None, path=None):
         * CEC module database
         * Sandia Module database
         * CEC Inverter database
+        * Anton Driesse Inverter database
 
     and return it as a pandas DataFrame.
 
@@ -1062,6 +1080,7 @@ def retrieve_sam(name=None, path=None):
           (CEC is only current inverter db available; tag kept for
           backwards compatibility)
         * 'SandiaMod' - returns the Sandia Module database
+        * 'ADRInverter' - returns the ADR Inverter database
 
     path : None or string
         Path to the SAM file. May also be a URL.
@@ -1104,9 +1123,6 @@ def retrieve_sam(name=None, path=None):
     Name: AE_Solar_Energy__AE6_0__277V__277V__CEC_2012_, dtype: float64
     '''
 
-    pvlib_path = os.path.dirname(os.path.abspath(__file__))
-    filepath = os.path.join(pvlib_path, 'data', 'LinkeTurbidities.mat')
-
     if name is not None:
         name = name.lower()
         data_path = os.path.join(
@@ -1117,6 +1133,8 @@ def retrieve_sam(name=None, path=None):
         elif name == 'sandiamod':
             csvdata = os.path.join(
                 data_path, 'sam-library-sandia-modules-2015-6-30.csv')
+        elif name == 'adrinverter':
+            csvdata = os.path.join(data_path, 'adr-library-2013-10-01.csv')
         elif name in ['cecinverter', 'sandiainverter']:
             # Allowing either, to provide for old code,
             # while aligning with current expectations
@@ -1166,6 +1184,13 @@ def _parse_raw_sam_df(csvdata):
 
     df.index = parsedindex
     df = df.transpose()
+    if 'ADRCoefficients' in df.index:
+        ad_ce = 'ADRCoefficients'
+        # for each inverter, parses a string of coefficients like
+        # ' 1.33, 2.11, 3.12' into a list containing floats:
+        # [1.33, 2.11, 3.12]
+        df.loc[ad_ce] = df.loc[ad_ce].map(lambda x: list(
+            map(float, x.strip(' []').split())))
 
     return df
 
@@ -1258,7 +1283,6 @@ def sapm(effective_irradiance, temp_cell, module):
     T0 = 25
     q = 1.60218e-19  # Elementary charge in units of coulombs
     kb = 1.38066e-23  # Boltzmann's constant in units of J/K
-    E0 = 1000
 
     Ee = effective_irradiance
 
@@ -2033,6 +2057,120 @@ def snlinverter(v_dc, p_dc, inverter):
     return ac_power
 
 
+def adrinverter(v_dc, p_dc, inverter, vtol=0.10):
+    r'''
+    Converts DC power and voltage to AC power using Anton Driesse's
+    Grid-Connected PV Inverter efficiency model
+
+    Parameters
+    ----------
+    v_dc : numeric
+        A scalar or pandas series of DC voltages, in volts, which are provided
+        as input to the inverter. If Vdc and Pdc are vectors, they must be
+        of the same size. v_dc must be >= 0. (V)
+
+    p_dc : numeric
+        A scalar or pandas series of DC powers, in watts, which are provided
+        as input to the inverter. If Vdc and Pdc are vectors, they must be
+        of the same size. p_dc must be >= 0. (W)
+
+    inverter : dict-like
+        A dict-like object defining the inverter to be used, giving the
+        inverter performance parameters according to the model
+        developed by Anton Driesse [1].
+        A set of inverter performance parameters may be loaded from the
+        supplied data table using retrievesam.
+        See Notes for required keys.
+
+    vtol : numeric
+        A unit-less fraction that determines how far the efficiency model is 
+        allowed to extrapolate beyond the inverter's normal input voltage 
+        operating range. 0.0 <= vtol <= 1.0
+
+    Returns
+    -------
+    ac_power : numeric
+        A numpy array or pandas series of modeled AC power output given the
+        input DC voltage, v_dc, and input DC power, p_dc. When ac_power would
+        be greater than pac_max, it is set to p_max to represent inverter
+        "clipping". When ac_power would be less than -p_nt (energy consumed
+        rather  than produced) then ac_power is set to -p_nt to represent
+        nightly power losses. ac_power is not adjusted for maximum power point
+        tracking (MPPT) voltage windows or maximum current limits of the
+        inverter.
+
+    Notes
+    -----
+
+    Required inverter keys are:
+
+    =======   ============================================================
+    Column    Description
+    =======   ============================================================
+    p_nom     The nominal power value used to normalize all power values,
+              typically the DC power needed to produce maximum AC power 
+              output, (W).
+
+    v_nom     The nominal DC voltage value used to normalize DC voltage 
+              values, typically the level at which the highest efficiency 
+              is achieved, (V).
+
+    pac_max   The maximum AC output power value, used to clip the output 
+              if needed, (W).
+
+    ce_list   This is a list of 9 coefficients that capture the influence
+              of input voltage and power on inverter losses, and thereby
+              efficiency.
+
+    p_nt      ac-power consumed by inverter at night (night tare) to 
+              maintain circuitry required to sense PV array voltage, (W).
+    =======   ============================================================
+
+    References
+    ----------
+    [1] Beyond the Curves: Modeling the Electrical Efficiency
+        of Photovoltaic Inverters, PVSC 2008, Anton Driesse et. al.
+
+    See also
+    --------
+    sapm
+    singlediode
+    '''
+
+    p_nom = inverter['Pnom']
+    v_nom = inverter['Vnom']
+    pac_max = inverter['Pacmax']
+    p_nt = inverter['Pnt']
+    ce_list = inverter['ADRCoefficients']
+    v_max = inverter['Vmax']
+    v_min = inverter['Vmin']
+    vdc_max = inverter['Vdcmax']
+    mppt_hi = inverter['MPPTHi']
+    mppt_low = inverter['MPPTLow']
+
+    v_lim_upper = np.nanmax([v_max, vdc_max, mppt_hi])*(1+vtol)
+    v_lim_lower = np.nanmax([v_min, mppt_low])*(1-vtol)
+
+    pdc = p_dc/p_nom
+    vdc = v_dc/v_nom
+    poly = np.array([pdc**0, pdc, pdc**2, vdc-1, pdc*(vdc-1),
+                     pdc**2*(vdc-1), 1/vdc-1, pdc*(1./vdc-1),
+                     pdc**2*(1./vdc-1)])
+    p_loss = np.dot(np.array(ce_list), poly)
+    ac_power = p_nom * (pdc-p_loss)
+    p_nt = -1*np.absolute(p_nt)
+
+    ac_power = np.where((v_lim_upper < v_dc) | (v_dc < v_lim_lower),
+                        np.nan, ac_power)
+    ac_power = np.where((ac_power < p_nt) | (vdc == 0), p_nt, ac_power)
+    ac_power = np.where(ac_power > pac_max, pac_max, ac_power)
+
+    if isinstance(p_dc, pd.Series):
+        ac_power = pd.Series(ac_power, index=pdc.index)
+
+    return ac_power
+
+
 def scale_voltage_current_power(data, voltage=1, current=1):
     """
     Scales the voltage, current, and power of the DataFrames
