@@ -9,8 +9,6 @@ Calculate the solar position using a variety of methods/packages.
 
 from __future__ import division
 import os
-import logging
-pvl_logger = logging.getLogger('pvlib')
 import datetime as dt
 try:
     from importlib import reload
@@ -20,13 +18,14 @@ except ImportError:
     except ImportError:
         pass
 
-import warnings
-
 import numpy as np
 import pandas as pd
 
 from pvlib import atmosphere
-from pvlib.tools import localize_to_utc, datetime_to_djd, djd_to_datetime
+from pvlib.tools import datetime_to_djd, djd_to_datetime
+
+import logging
+pvl_logger = logging.getLogger('pvlib')
 
 
 def get_solarposition(time, latitude, longitude,
@@ -39,26 +38,33 @@ def get_solarposition(time, latitude, longitude,
     Parameters
     ----------
     time : pandas.DatetimeIndex
+
     latitude : float
+
     longitude : float
+
     altitude : None or float
         If None, computed from pressure. Assumed to be 0 m
         if pressure is also None.
+
     pressure : None or float
         If None, computed from altitude. Assumed to be 101325 Pa
         if altitude is also None.
+
     method : string
-        'pyephem' uses the PyEphem package: :func:`pyephem`
-
-        'nrel_c' uses the NREL SPA C code [3]: :func:`spa_c`
-
         'nrel_numpy' uses an implementation of the NREL SPA algorithm
-        described in [1] (default): :func:`spa_python`
+        described in [1] (default, recommended): :py:func:`spa_python`
 
         'nrel_numba' uses an implementation of the NREL SPA algorithm
-        described in [1], but also compiles the code first: :func:`spa_python`
+        described in [1], but also compiles the code first:
+        :py:func:`spa_python`
+
+        'pyephem' uses the PyEphem package: :py:func:`pyephem`
+
+        'ephemeris' uses the pvlib ephemeris code: :py:func:`ephemeris`
+
+        'nrel_c' uses the NREL SPA C code [3]: :py:func:`spa_c`
 
-        'ephemeris' uses the pvlib ephemeris code: :func:`ephemeris`
     temperature : float
         Degrees C.
 
@@ -115,13 +121,15 @@ def spa_c(time, latitude, longitude, pressure=101325, altitude=0,
           raw_spa_output=False):
     """
     Calculate the solar position using the C implementation of the NREL
-    SPA code
+    SPA code.
 
     The source files for this code are located in './spa_c_files/', along with
     a README file which describes how the C code is wrapped in Python.
     Due to license restrictions, the C code must be downloaded seperately
     and used in accordance with it's license.
 
+    This function is slower and no more accurate than :py:func:`spa_python`.
+
     Parameters
     ----------
     time : pandas.DatetimeIndex
@@ -154,7 +162,8 @@ def spa_c(time, latitude, longitude, pressure=101325, altitude=0,
     ----------
     NREL SPA code: http://rredc.nrel.gov/solar/codesandalgorithms/spa/
 
-    USNO delta T: http://www.usno.navy.mil/USNO/earth-orientation/eo-products/long-term
+    USNO delta T:
+    http://www.usno.navy.mil/USNO/earth-orientation/eo-products/long-term
 
     See also
     --------
@@ -184,7 +193,7 @@ def spa_c(time, latitude, longitude, pressure=101325, altitude=0,
                                 hour=date.hour,
                                 minute=date.minute,
                                 second=date.second,
-                                timezone=0,  # must input localized or utc times
+                                timezone=0,  # must input localized or utc time
                                 latitude=latitude,
                                 longitude=longitude,
                                 elevation=altitude,
@@ -238,7 +247,7 @@ def _spa_python_import(how):
 
 
 def spa_python(time, latitude, longitude,
-               altitude=0, pressure=101325, temperature=12, delta_t=None,
+               altitude=0, pressure=101325, temperature=12, delta_t=67.0,
                atmos_refract=None, how='numpy', numthreads=4, **kwargs):
     """
     Calculate the solar position using a python implementation of the
@@ -261,7 +270,12 @@ def spa_python(time, latitude, longitude,
     temperature : int or float, optional
         avg. yearly air temperature in degrees C.
     delta_t : float, optional
+        If delta_t is None, uses spa.calculate_deltat
+        using time.year and time.month from pandas.DatetimeIndex.
+        For most simulations specifing delta_t is sufficient.
         Difference between terrestrial time and UT1.
+        *Note: delta_t = None will break code using nrel_numba,
+        this will be fixed in a future version.*
         The USNO has historical and forecasted delta_t [3].
     atmos_refrac : float, optional
         The approximate atmospheric refraction (in degrees)
@@ -293,7 +307,8 @@ def spa_python(time, latitude, longitude,
     [2] I. Reda and A. Andreas, Corrigendum to Solar position algorithm for
     solar radiation applications. Solar Energy, vol. 81, no. 6, p. 838, 2007.
 
-    [3] USNO delta T: http://www.usno.navy.mil/USNO/earth-orientation/eo-products/long-term
+    [3] USNO delta T:
+    http://www.usno.navy.mil/USNO/earth-orientation/eo-products/long-term
 
     See also
     --------
@@ -308,7 +323,7 @@ def spa_python(time, latitude, longitude,
     lon = longitude
     elev = altitude
     pressure = pressure / 100  # pressure must be in millibars for calculation
-    delta_t = delta_t or 67.0
+
     atmos_refract = atmos_refract or 0.5667
 
     if not isinstance(time, pd.DatetimeIndex):
@@ -321,9 +336,11 @@ def spa_python(time, latitude, longitude,
 
     spa = _spa_python_import(how)
 
-    app_zenith, zenith, app_elevation, elevation, azimuth, eot = spa.solar_position(
-        unixtime, lat, lon, elev, pressure, temperature, delta_t,
-        atmos_refract, numthreads)
+    delta_t = delta_t or spa.calculate_deltat(time.year, time.month)
+
+    app_zenith, zenith, app_elevation, elevation, azimuth, eot = \
+        spa.solar_position(unixtime, lat, lon, elev, pressure, temperature,
+                           delta_t, atmos_refract, numthreads)
 
     result = pd.DataFrame({'apparent_zenith': app_zenith, 'zenith': zenith,
                            'apparent_elevation': app_elevation,
@@ -335,7 +352,7 @@ def spa_python(time, latitude, longitude,
 
 
 def get_sun_rise_set_transit(time, latitude, longitude, how='numpy',
-                             delta_t=None,
+                             delta_t=67.0,
                              numthreads=4):
     """
     Calculate the sunrise, sunset, and sun transit times using the
@@ -353,7 +370,12 @@ def get_sun_rise_set_transit(time, latitude, longitude, how='numpy',
     latitude : float
     longitude : float
     delta_t : float, optional
+        If delta_t is None, uses spa.calculate_deltat
+        using time.year and time.month from pandas.DatetimeIndex.
+        For most simulations specifing delta_t is sufficient.
         Difference between terrestrial time and UT1.
+        *Note: delta_t = None will break code using nrel_numba,
+        this will be fixed in a future version.
         By default, use USNO historical data and predictions
     how : str, optional
         Options are 'numpy' or 'numba'. If numba >= 0.17.0
@@ -380,7 +402,6 @@ def get_sun_rise_set_transit(time, latitude, longitude, how='numpy',
 
     lat = latitude
     lon = longitude
-    delta_t = delta_t or 67.0
 
     if not isinstance(time, pd.DatetimeIndex):
         try:
@@ -394,6 +415,8 @@ def get_sun_rise_set_transit(time, latitude, longitude, how='numpy',
 
     spa = _spa_python_import(how)
 
+    delta_t = delta_t or spa.calculate_deltat(time.year, time.month)
+
     transit, sunrise, sunset = spa.transit_sunrise_sunset(
         unixtime, lat, lon, delta_t, numthreads)
 
@@ -773,7 +796,7 @@ def pyephem_earthsun_distance(time):
     return pd.Series(earthsun, index=time)
 
 
-def nrel_earthsun_distance(time, how='numpy', delta_t=None, numthreads=4):
+def nrel_earthsun_distance(time, how='numpy', delta_t=67.0, numthreads=4):
     """
     Calculates the distance from the earth to the sun using the
     NREL SPA algorithm described in [1].
@@ -788,7 +811,12 @@ def nrel_earthsun_distance(time, how='numpy', delta_t=None, numthreads=4):
         to machine code and run them multithreaded.
 
     delta_t : float, optional
+        If delta_t is None, uses spa.calculate_deltat
+        using time.year and time.month from pandas.DatetimeIndex.
+        For most simulations specifing delta_t is sufficient.
         Difference between terrestrial time and UT1.
+        *Note: delta_t = None will break code using nrel_numba,
+        this will be fixed in a future version.*
         By default, use USNO historical data and predictions
 
     numthreads : int, optional
@@ -796,7 +824,7 @@ def nrel_earthsun_distance(time, how='numpy', delta_t=None, numthreads=4):
 
     Returns
     -------
-    R : pd.Series
+    dist : pd.Series
         Earth-sun distance in AU.
 
     References
@@ -805,7 +833,6 @@ def nrel_earthsun_distance(time, how='numpy', delta_t=None, numthreads=4):
     radiation applications. Technical report: NREL/TP-560- 34302. Golden,
     USA, http://www.nrel.gov.
     """
-    delta_t = delta_t or 67.0
 
     if not isinstance(time, pd.DatetimeIndex):
         try:
@@ -817,11 +844,13 @@ def nrel_earthsun_distance(time, how='numpy', delta_t=None, numthreads=4):
 
     spa = _spa_python_import(how)
 
-    R = spa.earthsun_distance(unixtime, delta_t, numthreads)
+    delta_t = delta_t or spa.calculate_deltat(time.year, time.month)
 
-    R = pd.Series(R, index=time)
+    dist = spa.earthsun_distance(unixtime, delta_t, numthreads)
 
-    return R
+    dist = pd.Series(dist, index=time)
+
+    return dist
 
 
 def _calculate_simple_day_angle(dayofyear):
